@@ -84,7 +84,9 @@ namespace stan {
 
     // see bare_type_grammar_def.hpp for original
     struct set_val4 {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2>
       struct result<F(T1, T2)> { typedef void type; };
       template <typename T1, typename T2>
@@ -96,7 +98,9 @@ namespace stan {
     boost::phoenix::function<set_val4> set_val4_f;
 
     struct validate_return_allowed {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
       void operator()(var_origin origin,
@@ -116,7 +120,9 @@ namespace stan {
     boost::phoenix::function<validate_return_allowed> validate_return_allowed_f;
 
     struct validate_void_return_allowed {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
       void operator()(var_origin origin,
@@ -139,7 +145,9 @@ namespace stan {
 
 
     struct validate_assignment {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3,
                 typename T4, typename T5>
       struct result<F(T1, T2, T3, T4, T5)> { typedef void type; };
@@ -243,7 +251,9 @@ namespace stan {
     boost::phoenix::function<validate_assignment> validate_assignment_f;
 
     struct validate_sample {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3, typename T4>
       struct result<F(T1, T2, T3, T4)> { typedef void type; };
 
@@ -263,6 +273,7 @@ namespace stan {
                       const variable_map& var_map,
                       bool& pass,
                       std::ostream& error_msgs) const {
+        static const bool user_facing = true;
         std::vector<expr_type> arg_types;
         arg_types.push_back(s.expr_.expression_type());
         for (size_t i = 0; i < s.dist_.args_.size(); ++i)
@@ -309,10 +320,10 @@ namespace stan {
 
         // test for LHS not being purely a variable
         if (has_non_param_var(s.expr_, var_map)) {
-          // FIXME:  really want to get line numbers in here too
+          // TODO(carpenter):  really want to get line numbers in here too
           error_msgs << "Warning (non-fatal):"
              << std::endl
-             << " Left-hand side of sampling statement (~) may contain a"
+             << "Left-hand side of sampling statement (~) may contain a"
              << " non-linear transform of a parameter or local variable."
              << std::endl
              << "If so, you need to call increment_log_prob() with the log"
@@ -321,7 +332,7 @@ namespace stan {
              << "Left-hand-side of sampling statement:"
              << std::endl
              << "    ";
-          generate_expression(s.expr_, error_msgs);
+          generate_expression(s.expr_, user_facing, error_msgs);
           error_msgs << " ~ " << function_name << "(...)"
                      << std::endl;
         }
@@ -332,7 +343,7 @@ namespace stan {
                        << " must be univariate."
                        << std::endl
                        << "  Found outcome expression: ";
-            generate_expression(s.expr_, error_msgs);
+            generate_expression(s.expr_, user_facing, error_msgs);
             error_msgs << std::endl
                        << "  with non-univariate type: "
                        << s.expr_.expression_type()
@@ -346,7 +357,7 @@ namespace stan {
                          << " must be univariate."
                          << std::endl
                          << "  Found parameter expression: ";
-              generate_expression(s.dist_.args_[i], error_msgs);
+              generate_expression(s.dist_.args_[i], user_facing, error_msgs);
               error_msgs << std::endl
                          << "  with non-univariate type: "
                          << s.dist_.args_[i].expression_type()
@@ -361,7 +372,7 @@ namespace stan {
                      << " must be univariate."
                      << std::endl
                      << "  Found lower bound expression: ";
-          generate_expression(s.truncation_.low_, error_msgs);
+          generate_expression(s.truncation_.low_, user_facing, error_msgs);
           error_msgs << std::endl
                      << "  with non-univariate type: "
                      << s.truncation_.low_.expression_type()
@@ -375,7 +386,7 @@ namespace stan {
                      << " must be univariate."
                      << std::endl
                      << "  Found upper bound expression: ";
-          generate_expression(s.truncation_.high_, error_msgs);
+          generate_expression(s.truncation_.high_, user_facing, error_msgs);
           error_msgs << std::endl
                      << "  with non-univariate type: "
                      << s.truncation_.high_.expression_type()
@@ -433,17 +444,20 @@ namespace stan {
     boost::phoenix::function<validate_sample> validate_sample_f;
 
     struct expression_as_statement {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
       void operator()(bool& pass,
                       const stan::lang::expression& expr,
                       std::stringstream& error_msgs) const {
+        static const bool user_facing = true;
         if (expr.expression_type() != VOID_T) {
           error_msgs << "Illegal statement beginning with non-void"
                      << " expression parsed as"
                      << std::endl << "  ";
-          generate_expression(expr.expr_, error_msgs);
+          generate_expression(expr.expr_, user_facing, error_msgs);
           error_msgs << std::endl
                      << "Not a legal assignment, sampling, or function"
                      << " statement.  Note that"
@@ -474,7 +488,9 @@ namespace stan {
     boost::phoenix::function<expression_as_statement> expression_as_statement_f;
 
     struct unscope_locals {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2>
       struct result<F(T1, T2)> { typedef void type; };
       void operator()(const std::vector<var_decl>& var_decls,
@@ -486,7 +502,9 @@ namespace stan {
     boost::phoenix::function<unscope_locals> unscope_locals_f;
 
     struct add_while_condition {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3, typename T4>
       struct result<F(T1, T2, T3, T4)> { typedef void type; };
       void operator()(while_statement& ws,
@@ -506,7 +524,9 @@ namespace stan {
     boost::phoenix::function<add_while_condition> add_while_condition_f;
 
     struct add_while_body {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2>
       struct result<F(T1, T2)> { typedef void type; };
       void operator()(while_statement& ws,
@@ -517,7 +537,9 @@ namespace stan {
     boost::phoenix::function<add_while_body> add_while_body_f;
 
     struct add_loop_identifier {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3, typename T4,
                 typename T5>
       struct result<F(T1, T2, T3, T4, T5)> { typedef void type; };
@@ -540,7 +562,9 @@ namespace stan {
     boost::phoenix::function<add_loop_identifier> add_loop_identifier_f;
 
     struct remove_loop_identifier {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2>
       struct result<F(T1, T2)> { typedef void type; };
       void operator()(const std::string& name,
@@ -551,7 +575,9 @@ namespace stan {
     boost::phoenix::function<remove_loop_identifier> remove_loop_identifier_f;
 
     struct validate_int_expr2 {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
 
@@ -571,7 +597,9 @@ namespace stan {
     boost::phoenix::function<validate_int_expr2> validate_int_expr2_f;
 
     struct validate_allow_sample {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
 
@@ -593,7 +621,9 @@ namespace stan {
     boost::phoenix::function<validate_allow_sample> validate_allow_sample_f;
 
     struct validate_non_void_expression {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
 
@@ -611,7 +641,9 @@ namespace stan {
     validate_non_void_expression_f;
 
     struct add_line_number {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1, typename T2, typename T3>
       struct result<F(T1, T2, T3)> { typedef void type; };
       template <typename T, typename It>
@@ -625,7 +657,9 @@ namespace stan {
     boost::phoenix::function<add_line_number> add_line_number_f;
 
     struct set_void_return {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1>
       struct result<F(T1)> { typedef void type; };
       void operator()(return_statement& s) const {
@@ -635,7 +669,9 @@ namespace stan {
     boost::phoenix::function<set_void_return> set_void_return_f;
 
     struct set_no_op {
+      //! @cond Doxygen_Suppress
       template <class> struct result;
+      //! @endcond
       template <typename F, typename T1>
       struct result<F(T1)> { typedef void type; };
       void operator()(no_op_statement& s) const {
@@ -676,6 +712,7 @@ namespace stan {
       //   _r2 source of variables allowed for assignments
       //   _r3 true if return_r allowed
 
+      // raw[ ] just to wrap to get line numbers
       statement_r.name("statement");
       statement_r
         = raw[statement_sub_r(_r1, _r2, _r3)[set_val4_f(_val, _1)]]
