@@ -22,10 +22,15 @@ namespace stan {
           (algorithm->arg("hmc")->arg("engine")->arg("nuts"));
 
         double epsilon
-          = dynamic_cast<stan::services::real_argument*>(hmc->arg("stepsize"))->value();
+          = dynamic_cast<stan::services::real_argument*>(hmc->arg("stepsize"))
+          ->value();
         double epsilon_jitter
-          = dynamic_cast<stan::services::real_argument*>(hmc->arg("stepsize_jitter"))->value();
-        int max_depth = dynamic_cast<stan::services::int_argument*>(base->arg("max_depth"))->value();
+          = dynamic_cast<stan::services::real_argument*>(
+                                                 hmc->arg("stepsize_jitter"))
+          ->value();
+        int max_depth
+          = dynamic_cast<stan::services::int_argument*>(base->arg("max_depth"))
+          ->value();
 
         dynamic_cast<Sampler*>(sampler)->set_nominal_stepsize(epsilon);
         dynamic_cast<Sampler*>(sampler)->set_stepsize_jitter(epsilon_jitter);
