@@ -1,10 +1,11 @@
 #ifndef STAN_SERVICES_MCMC_PRINT_PROGRESS_HPP
 #define STAN_SERVICES_MCMC_PRINT_PROGRESS_HPP
 
+#include <stan/services/io/do_print.hpp>
 #include <cmath>
 #include <iomanip>
-#include <stan/services/io/do_print.hpp>
 #include <iostream>
+#include <string>
 
 namespace stan {
   namespace services {
@@ -18,7 +19,7 @@ namespace stan {
                           const std::string prefix,
                           const std::string suffix,
                           std::ostream& o) {
-        int it_print_width = std::ceil(std::log10((double) finish));
+        int it_print_width = std::ceil(std::log10(static_cast<double>(finish)));
         if (io::do_print(m, (start + m + 1 == finish), refresh)) {
           o << prefix;
           o << "Iteration: ";
