@@ -15,8 +15,11 @@
 
 #include <stan/math/prim/mat/err/check_square.hpp>
 #include <stan/math/prim/mat/err/check_lower_triangular.hpp>
-#include <stan/math/prim/scal/err/check_size_match.hpp>
+#include <stan/math/prim/scal/err/check_finite.hpp>
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
+#include <stan/math/prim/scal/err/check_positive.hpp>
+#include <stan/math/prim/scal/err/check_size_match.hpp>
+#include <stan/math/prim/scal/err/domain_error.hpp>
 
 #include <stan/variational/base_family.hpp>
 
@@ -208,15 +211,13 @@ namespace stan {
        * @return                   a sample from the variational distribution
        */
       template <class BaseRNG>
-      Eigen::VectorXd sample(BaseRNG& rng) const {
-        Eigen::VectorXd eta = Eigen::VectorXd::Zero(dimension_);
-
+      void sample(BaseRNG& rng, Eigen::VectorXd& eta) const {
         // Draw from standard normal and transform to real-coordinate space
         for (int d = 0; d < dimension_; ++d) {
           eta(d) = stan::math::normal_rng(0, 1, rng);
         }
 
-        return transform(eta);
+        eta = transform(eta);
       }
 
       /**
@@ -225,12 +226,12 @@ namespace stan {
        * parallel. It uses the same gradient computed from a set of Monte Carlo
        * samples
        *
-       * @tparam M                     class of model
-       * @tparam BaseRNG               class of random number generator
-       * @param  elbo_grad             parameters to store "blackbox" gradient
-       * @param  cont_params           continuous parameters
-       * @param  n_monte_carlo_grad    number of samples for gradient computation
-       * @param  print_stream          stream for convergence assessment output
+       * @param elbo_grad             parameters to store "blackbox" gradient
+       * @param m                     model
+       * @param cont_params           continuous parameters
+       * @param n_monte_carlo_grad    number of samples for gradient computation
+       * @param rng                   random number generator
+       * @param print_stream          stream for convergence assessment output
        */
       template <class M, class BaseRNG>
       void calc_grad(normal_fullrank& elbo_grad,
@@ -258,21 +259,36 @@ namespace stan {
         Eigen::VectorXd zeta = Eigen::VectorXd::Zero(dimension_);
 
         // Naive Monte Carlo integration
-        for (int i = 0; i < n_monte_carlo_grad; ++i) {
+        int i = 0;
+        int n_monte_carlo_drop = 0;
+        while (i < n_monte_carlo_grad) {
           // Draw from standard normal and transform to real-coordinate space
           for (int d = 0; d < dimension_; ++d) {
             eta(d) = stan::math::normal_rng(0, 1, rng);
           }
           zeta = transform(eta);
 
-          // Compute gradient step in real-coordinate space
-          stan::model::gradient(m, zeta, tmp_lp, tmp_mu_grad, print_stream);
+          try {
+            stan::model::gradient(m, zeta, tmp_lp, tmp_mu_grad, print_stream);
+            stan::math::check_finite(function, "Gradient of mu", tmp_mu_grad);
 
-          // Update gradient parameters
-          mu_grad += tmp_mu_grad;
-          for (int ii = 0; ii < dimension_; ++ii) {
-            for (int jj = 0; jj <= ii; ++jj) {
-              L_grad(ii, jj) += tmp_mu_grad(ii) * eta(jj);
+            mu_grad += tmp_mu_grad;
+            for (int ii = 0; ii < dimension_; ++ii) {
+              for (int jj = 0; jj <= ii; ++jj) {
+                L_grad(ii, jj) += tmp_mu_grad(ii) * eta(jj);
+              }
+            }
+            i += 1;
+          } catch (std::exception& e) {
+            this->write_error_msg_(print_stream, e);
+            n_monte_carlo_drop += 1;
+            if (n_monte_carlo_drop >= 5*n_monte_carlo_grad) {
+              const char* name = "The number of dropped evaluations";
+              const char* msg1 = "has reached its maximum amount (";
+              int y = 5*n_monte_carlo_grad;
+              const char* msg2 = "). Your model may be either severely "
+                "ill-conditioned or misspecified.";
+              stan::math::domain_error(function, name, y, msg1, msg2);
             }
           }
         }
